==> gproftpd-8.1.9.tar.gz: gproftpd-8.1.9/src/callbacks.h <==
#include <gtk/gtk.h>

int 
is_banned(char *user);

int 
user_exists(G_CONST_RETURN gchar *username);

int 
group_exists(G_CONST_RETURN gchar *groupname);

void 
list_users(GtkWidget *widget, gpointer user_data);

void 
list_server_values(GtkWidget *widget, gpointer user_data);

void 
list_entire(GtkWidget *widget, gpointer user_data);

void
on_online_button_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_offline_button_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_reread_button_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_gproftpd_window_map                 (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_shutdown_button_clicked             (GtkButton       *button,
                                        gpointer         user_data);

void
on_help_button_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_credits_button_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_kickban_button_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_kick_button_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_entire_save_button_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_servers_apply_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_useradd_button_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_randomize_button_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_info_textview_map                   (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_info_window_map                     (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_username_rand_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_password_rand_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_userlist_treeview_row_activated     (GtkTreeView     *treeview,
                                        GtkTreePath     *arg1,
                                        GtkTreeViewColumn *arg2,
                                        gpointer         user_data);

void
on_user_settings_delete_button_clicked (GtkButton       *button,
                                        gpointer         user_data);

void
on_user_settings_change_button_clicked (GtkButton       *button,
                                        gpointer         user_data);

void
on_user_settings_close_button_clicked (GtkButton       *button,
                                        gpointer         user_data);

void
on_user_settings_window_map            (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_restore_button_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_backup_button_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_syntaxcheck_button_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_save_entire_button_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_incoming_checkbutton_toggled        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_useradd_incoming_checkbutton_toggled
                                        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_disc_update_button_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_files_update_button_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_security_update_button_clicked      (GtkButton       *button,
                                        gpointer         user_data);

void
on_files_clear_button_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_files_update_button_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_shutdown_ok_button_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_userdir_select_ok_button_clicked    (GtkButton       *button,
                                        gpointer         user_data);

void
on_userdir_button_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_useradd_incoming_button_clicked     (GtkButton       *button,
                                        gpointer         user_data);

void
on_incoming_directory_ok_button_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_html_button_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_welcome_button_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_yes_default_question_button_clicked (GtkButton       *button,
                                        gpointer         user_data);

void
on_no_default_question_button_clicked  (GtkButton       *button,
                                        gpointer         user_data);

void
on_tls_generate_certificate_button_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_xfer_scrolledwindow_scroll_child    (GtkScrolledWindow *scrolledwindow,
                                        GtkScrollType    arg1,
                                        gboolean         arg2,
                                        gpointer         user_data);

gboolean
on_xfer_textview_scroll_event          (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_xfer_textview_set_scroll_adjustments
                                        (GtkTextView     *textview,
                                        GtkAdjustment   *arg1,
                                        GtkAdjustment   *arg2,
                                        gpointer         user_data);

gboolean
on_xfer_scrolledwindow_scroll_event    (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

gboolean
on_xfer_scrolledwindow_scroll_event    (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_xfer_scrolledwindow_scroll_child    (GtkScrolledWindow *scrolledwindow,
                                        GtkScrollType    arg1,
                                        gboolean         arg2,
                                        gpointer         user_data);

void
on_xfer_textview_set_scroll_adjustments
                                        (GtkTextView     *textview,
                                        GtkAdjustment   *arg1,
                                        GtkAdjustment   *arg2,
                                        gpointer         user_data);

gboolean
on_xfer_textview_scroll_event          (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_online_button_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_offline_button_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_change_password_button_clicked      (GtkButton       *button,
                                        gpointer         user_data);

void
on_question_userdel_delete_button_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_gplock_checkbutton_toggled          (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_add_systemuser_yes_button_clicked   (GtkButton       *button,
                                        gpointer         user_data);

void
on_add_systemuser_question_window_map  (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_servers_treeview_row_activated      (GtkTreeView     *treeview,
                                        GtkTreePath     *path,
                                        GtkTreeViewColumn *column,
                                        gpointer         user_data);

void
on_add_server_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_delete_server_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);


void
on_apply_server_changes_button_clicked (GtkButton       *button,
                                        gpointer         user_data);

void
on_import_users_button_clicked 	       (GtkButton       *button,
                                        gpointer         user_data);

==> gproftpd_8.2.2.orig.tar.gz: gproftpd-8.2.2/src/callbacks.h <==
#include <gtk/gtk.h>

int 
is_banned(char *user);

int 
user_exists(G_CONST_RETURN gchar *username);

int 
group_exists(G_CONST_RETURN gchar *groupname);

void 
list_users(GtkWidget *widget, gpointer user_data);

void 
list_server_values(GtkWidget *widget, gpointer user_data);

void 
list_entire(GtkWidget *widget, gpointer user_data);

void
on_online_button_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_offline_button_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_reread_button_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_gproftpd_window_map                 (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_shutdown_button_clicked             (GtkButton       *button,
                                        gpointer         user_data);

void
on_help_button_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_credits_button_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_kickban_button_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_kick_button_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_entire_save_button_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_servers_apply_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_useradd_button_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_randomize_button_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_info_textview_map                   (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_info_window_map                     (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_username_rand_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_password_rand_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_userlist_treeview_row_activated     (GtkTreeView     *treeview,
                                        GtkTreePath     *arg1,
                                        GtkTreeViewColumn *arg2,
                                        gpointer         user_data);

void
on_user_settings_delete_button_clicked (GtkButton       *button,
                                        gpointer         user_data);

void
on_user_settings_change_button_clicked (GtkButton       *button,
                                        gpointer         user_data);

void
on_user_settings_close_button_clicked (GtkButton       *button,
                                        gpointer         user_data);

void
on_user_settings_window_map            (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_restore_button_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_backup_button_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_syntaxcheck_button_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_save_entire_button_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_incoming_checkbutton_toggled        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_useradd_incoming_checkbutton_toggled
                                        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_disc_update_button_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_files_update_button_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_security_update_button_clicked      (GtkButton       *button,
                                        gpointer         user_data);

void
on_files_clear_button_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_files_update_button_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_shutdown_ok_button_clicked          (GtkButton       *button,
                                        gpointer         user_data);

void
on_userdir_select_ok_button_clicked    (GtkButton       *button,
                                        gpointer         user_data);

void
on_userdir_button_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_useradd_incoming_button_clicked     (GtkButton       *button,
                                        gpointer         user_data);

void
on_incoming_directory_ok_button_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_html_button_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_welcome_button_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_yes_default_question_button_clicked (GtkButton       *button,
                                        gpointer         user_data);

void
on_no_default_question_button_clicked  (GtkButton       *button,
                                        gpointer         user_data);

void
on_tls_generate_certificate_button_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_xfer_scrolledwindow_scroll_child    (GtkScrolledWindow *scrolledwindow,
                                        GtkScrollType    arg1,
                                        gboolean         arg2,
                                        gpointer         user_data);

gboolean
on_xfer_textview_scroll_event          (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_xfer_textview_set_scroll_adjustments
                                        (GtkTextView     *textview,
                                        GtkAdjustment   *arg1,
                                        GtkAdjustment   *arg2,
                                        gpointer         user_data);

gboolean
on_xfer_scrolledwindow_scroll_event    (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

gboolean
on_xfer_scrolledwindow_scroll_event    (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_xfer_scrolledwindow_scroll_child    (GtkScrolledWindow *scrolledwindow,
                                        GtkScrollType    arg1,
                                        gboolean         arg2,
                                        gpointer         user_data);

void
on_xfer_textview_set_scroll_adjustments
                                        (GtkTextView     *textview,
                                        GtkAdjustment   *arg1,
                                        GtkAdjustment   *arg2,
                                        gpointer         user_data);

gboolean
on_xfer_textview_scroll_event          (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_online_button_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_offline_button_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_change_password_button_clicked      (GtkButton       *button,
                                        gpointer         user_data);

void
on_question_userdel_delete_button_clicked
                                        (GtkButton       *button,
                                        gpointer         user_data);

void
on_gplock_checkbutton_toggled          (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_add_systemuser_yes_button_clicked   (GtkButton       *button,
                                        gpointer         user_data);

void
on_add_systemuser_question_window_map  (GtkWidget       *widget,
                                        gpointer         user_data);

void
on_servers_treeview_row_clicked(GtkTreeView *treeview, 
				GdkEventButton *event, 
				gpointer user_data);

void
on_add_server_button_clicked           (GtkButton       *button,
                                        gpointer         user_data);

void
on_delete_server_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_apply_server_changes_button_clicked (GtkButton       *button,
                                        gpointer         user_data);

void
on_import_users_button_clicked 	       (GtkButton       *button,
                                        gpointer         user_data);
